;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elfeed-curate" "20251026.311"
  "Elfeed entry curation."
  '((emacs  "27.1")
    (elfeed "3.4.1"))
  :url "https://github.com/rnadler/elfeed-curate"
  :commit "c91caf36cefadd818c893ac219265367f9f7945d"
  :revdesc "c91caf36cefa"
  :keywords '("news")
  :authors '(("Robert Nadler" . "robert.nadler@gmail.com"))
  :maintainers '(("Robert Nadler" . "robert.nadler@gmail.com")))
